@@ -156,6 +156,13 @@ class MainWindow(QtWidgets.QMainWindow):
             self.time.start(1000)
             self.tempPolling.start(10000)
             
+            if sys.platform == 'linux':
+                try:
+                    result=subprocess.check_output(['sudo','chmod','777','/home/pi/app/spotii/profile.json']).decode("utf-8")
+                    
+                except Exception as error:
+                    print(error)
+            
             
         except Exception as error:
             print(error)
